==> ignite-indexing-8.7.23-sources.jar: org/apache/ignite/internal/processors/query/h2/twostep/msg/GridH2Uuid.java <==
/*
 * Copyright 2019 GridGain Systems, Inc. and Contributors.
 *
 * Licensed under the GridGain Community Edition License (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.gridgain.com/products/software/community-edition/gridgain-community-edition-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.query.h2.twostep.msg;

import java.nio.ByteBuffer;
import org.apache.ignite.internal.GridKernalContext;
import org.apache.ignite.plugin.extensions.communication.MessageReader;
import org.apache.ignite.plugin.extensions.communication.MessageWriter;
import org.h2.value.Value;
import org.h2.value.ValueUuid;

/**
 * H2 Uuid.
 */
public class GridH2Uuid extends GridH2ValueMessage {
    /** */
    private long high;

    /** */
    private long low;

    /**
     *
     */
    public GridH2Uuid() {
        // No-op.
    }

    /**
     * @param val Value.
     */
    public GridH2Uuid(Value val) {
        assert val.getType().getValueType() == Value.UUID : val.getType();

        ValueUuid uuid = (ValueUuid)val;

        high = uuid.getHigh();
        low = uuid.getLow();
    }

    /** {@inheritDoc} */
    @Override public Value value(GridKernalContext ctx) {
        return ValueUuid.get(high, low);
    }

    /** {@inheritDoc} */
    @Override public boolean writeTo(ByteBuffer buf, MessageWriter writer) {
        writer.setBuffer(buf);

        if (!super.writeTo(buf, writer))
            return false;

        if (!writer.isHeaderWritten()) {
            if (!writer.writeHeader(directType(), fieldsCount()))
                return false;

            writer.onHeaderWritten();
        }

        switch (writer.state()) {
            case 0:
                if (!writer.writeLong("high", high))
                    return false;

                writer.incrementState();

            case 1:
                if (!writer.writeLong("low", low))
                    return false;

                writer.incrementState();

        }

        return true;
    }

    /** {@inheritDoc} */
    @Override public boolean readFrom(ByteBuffer buf, MessageReader reader) {
        reader.setBuffer(buf);

        if (!reader.beforeMessageRead())
            return false;

        if (!super.readFrom(buf, reader))
            return false;

        switch (reader.state()) {
            case 0:
                high = reader.readLong("high");

                if (!reader.isLastRead())
                    return false;

                reader.incrementState();

            case 1:
                low = reader.readLong("low");

                if (!reader.isLastRead())
                    return false;

                reader.incrementState();

        }

        return reader.afterMessageRead(GridH2Uuid.class);
    }

    /** {@inheritDoc} */
    @Override public short directType() {
        return -20;
    }

    /** {@inheritDoc} */
    @Override public byte fieldsCount() {
        return 2;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return ValueUuid.get(high, low).getString();
    }
}

==> ignite-indexing-8.9.14-p2-sources.jar: org/apache/ignite/internal/processors/query/h2/twostep/msg/GridH2Uuid.java <==
/*
 * Copyright 2019 GridGain Systems, Inc. and Contributors.
 *
 * Licensed under the GridGain Community Edition License (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.gridgain.com/products/software/community-edition/gridgain-community-edition-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.query.h2.twostep.msg;

import java.nio.ByteBuffer;
import org.apache.ignite.internal.GridKernalContext;
import org.apache.ignite.plugin.extensions.communication.MessageReader;
import org.apache.ignite.plugin.extensions.communication.MessageWriter;
import org.gridgain.internal.h2.value.Value;
import org.gridgain.internal.h2.value.ValueUuid;

/**
 * H2 Uuid.
 */
public class GridH2Uuid extends GridH2ValueMessage {
    /** */
    private long high;

    /** */
    private long low;

    /**
     *
     */
    public GridH2Uuid() {
        // No-op.
    }

    /**
     * @param val Value.
     */
    public GridH2Uuid(Value val) {
        assert val.getType().getValueType() == Value.UUID : val.getType();

        ValueUuid uuid = (ValueUuid)val;

        high = uuid.getHigh();
        low = uuid.getLow();
    }

    /** {@inheritDoc} */
    @Override public Value value(GridKernalContext ctx) {
        return ValueUuid.get(high, low);
    }

    /** {@inheritDoc} */
    @Override public boolean writeTo(ByteBuffer buf, MessageWriter writer) {
        writer.setBuffer(buf);

        if (!super.writeTo(buf, writer))
            return false;

        if (!writer.isHeaderWritten()) {
            if (!writer.writeHeader(directType(), fieldsCount()))
                return false;

            writer.onHeaderWritten();
        }

        switch (writer.state()) {
            case 0:
                if (!writer.writeLong("high", high))
                    return false;

                writer.incrementState();

            case 1:
                if (!writer.writeLong("low", low))
                    return false;

                writer.incrementState();

        }

        return true;
    }

    /** {@inheritDoc} */
    @Override public boolean readFrom(ByteBuffer buf, MessageReader reader) {
        reader.setBuffer(buf);

        if (!reader.beforeMessageRead())
            return false;

        if (!super.readFrom(buf, reader))
            return false;

        switch (reader.state()) {
            case 0:
                high = reader.readLong("high");

                if (!reader.isLastRead())
                    return false;

                reader.incrementState();

            case 1:
                low = reader.readLong("low");

                if (!reader.isLastRead())
                    return false;

                reader.incrementState();

        }

        return reader.afterMessageRead(GridH2Uuid.class);
    }

    /** {@inheritDoc} */
    @Override public short directType() {
        return -20;
    }

    /** {@inheritDoc} */
    @Override public byte fieldsCount() {
        return 2;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return ValueUuid.get(high, low).getString();
    }
}
